import re

hth_keywords = ["华体会", "hth", "HTH", "代理WEB", "代理web"]
ky_keywords = ["开云"]
jy_keywords = ["九游"]


def read_file(filename):
    try:
        with open(filename, 'r') as file:
            return file.read()
    except IOError as e:
        print(f"Error reading file {filename}: {e}")
        raise


def write_file(filename, content):
    try:
        with open(filename, 'w') as file:
            file.write(content)
    except IOError as e:
        print(f"Error writing to file {filename}: {e}")
        raise


def replace_urls(js_content, url_mapping):
    for placeholder, url in url_mapping.items():
        js_content = js_content.replace(placeholder, url)
    return js_content


def get_url_mapping(urls_with_context, template_type):
    categories = {"WEB": [], "H5": [], "全站": [], "体育": [], "棋牌": [], "电子": [],"web": [], "h5": [], "全站APP": [], "体育APP": []}
    # 遍历URLs及其前文本的元组列表进行分类
    for context, url in urls_with_context:
        key = context.strip().replace(" ", "")
        if key in categories:
            categories[key].append(url)

    # 构建映射字典，直接返回结果
    if template_type == 'hth':
        url_mapping = {
            "{{hthApp}}": categories.get("全站", [""])[0] if categories.get("全站", [""]) else categories.get("全站APP", [""])[0],
            "{{hthtyApp}}": categories.get("体育", [""])[0] if categories.get("体育", [""]) else categories.get("体育APP", [""])[0],
            "{{hthPc}}": categories.get("WEB", [""])[0] if categories.get("WEB", [""]) else categories.get("web", [""])[0],
            "{{hthH5}}": categories.get("H5", [""])[0] if categories.get("H5", [""]) else categories.get("h5", [""])[0]
        }
    elif template_type == 'ky':  # ky模板
        url_mapping = {
            "{{kyPc}}": categories.get("WEB", [""])[0],
            "{{kyPc2}}": categories.get("WEB", ["", ""])[1],
            "{{kyH51}}": categories.get("H5", [""])[0],
            "{{kyH52}}": categories.get("H5", ["", ""])[1],
            "{{kyApp1}}": categories.get("全站", [""])[0],
            "{{kyApp2}}": categories.get("体育", [""])[0],
            # "{{kyApp2}}": categories.get("全站", ["", ""])[1],
            "{{kyTy1}}": categories.get("体育", [""])[0],
            "{{kyTy2}}": categories.get("全站", [""])[0],
            # "{{kyTy2}}": categories.get("体育", ["", ""])[1]
        }
    elif template_type == 'jy':  # jy模板
        url_mapping = {
            "{{jyPc}}": categories.get("WEB", [""])[0],
            "{{jyH5}}": categories.get("H5", [""])[0],
            "{{jyApp}}": categories.get("全站", [""])[0],
            "{{jyQp}}": categories.get("棋牌", [""])[0],
            "{{jyDz}}": categories.get("电子", [""])[0],
            "{{jyFljPc}}": categories.get("WEB", [""])[1],
            "{{jyFljH5}}": categories.get("H5", [""])[1],
        }
    else:
        print('未知模板')
        return

    return url_mapping


def extract_urls(text):
    # seo_part_index = text.find("SEO 防拦截域名")
    # relevant_text = text[:seo_part_index] if seo_part_index != -1 else text
    pattern = r'(?:\n|^)\s*([^\n]*?)\s*(https?://[^\s]+)'
    matches = re.findall(pattern, text)
    return [(context.strip(), url) for context, url in matches]


def change_url(text, hth_template_path='/www/wwwroot/change_url/hth.js.template',
               ky_template_path='/www/wwwroot/change_url/ky.js.template',
               jy_template_path='/www/wwwroot/change_url/jy.js.template'):
    try:
        urls_with_context = extract_urls(text)
        expected_filename = None
        if any(keyword in text for keyword in hth_keywords):
            template_path = hth_template_path
            template_type = 'hth'
        elif any(keyword in text for keyword in ky_keywords):
            template_path = ky_template_path
            template_type = 'ky'
        elif any(keyword in text for keyword in jy_keywords):
            template_path = jy_template_path
            template_type = 'jy'
        else:
            return False, 'unknown.js'

        js_content = read_file(template_path)
        url_mapping = get_url_mapping(urls_with_context, template_type)
        updated_content = replace_urls(js_content, url_mapping)
        expected_filename = template_path.replace('.template', '')
        write_file(expected_filename, updated_content)

        return True, expected_filename
    except Exception as e:
        print(f"An error occurred: {e}")
        return False, expected_filename if expected_filename else 'unknown.js'

if __name__ == '__main__':
    text = '''#域名更换通知
通知：以下是最新域名：

web             
 https://www.e5vj65s.com:9961    【新】
h5                
https://www.g81mly.com:8553        
全站APP     
https://www.9n3nhg.vip:9017         
体育APP     
https://www.c9jngo.vip:6004      
代理web     
https://www.kvvgv.com:9043  
代理H5       
https://www.lt08m.com:9960                                                                                                                                                                                                                                                                                       
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 

备注：域名后面的数字为正常，请勿删除'''
    change_url(text,hth_template_path='template/hth.js.template',ky_template_path='template/ky.js.template',jy_template_path='template/jy.js.template')